..
   Copyright (C) 2015-2022 CERN.
   Invenio is free software; you can redistribute it and/or modify it
   under the terms of the MIT License; see LICENSE file for more details.


API Docs
========

.. automodule:: invenio_pages.ext
   :members:

Configuration
-------------

.. automodule:: invenio_pages.config
   :members:

Models
------

.. automodule:: invenio_pages.records.models
   :members:

Views
-----

.. automodule:: invenio_pages.views
   :members:
